==> eg_particle_interactions-v0.8.1-fabric-mc1.21.8-sources.jar: games/enchanted/eg_particle_interactions/common/particle/swirling/SwirlingParticle.java <==
package games.enchanted.eg_particle_interactions.common.particle.swirling;

import games.enchanted.eg_particle_interactions.common.util.MathHelpers;
import net.minecraft.class_3999;
import net.minecraft.class_4002;
import net.minecraft.class_4003;
import net.minecraft.class_4184;
import net.minecraft.class_4588;
import net.minecraft.class_638;
import org.jetbrains.annotations.NotNull;

public class SwirlingParticle extends class_4003 {
    protected float rotSpeed;
    protected float spinAcceleration;
    protected double swirlPeriod;
    protected float swirlStrength;
    protected final boolean shouldSwirl;

    protected SwirlingParticle(class_638 level, double x, double y, double z, double xSpeed, double ySpeed, double zSpeed, class_4002 spriteSet, boolean shouldSwirl) {
        super(level, x, y, z, xSpeed, ySpeed, zSpeed);
        this.field_3852 = xSpeed;
        this.field_3869 = ySpeed;
        this.field_3850 = zSpeed;
        this.field_3844 = 0.5f;

        this.field_17886 = spriteSet.method_18139(level.field_9229);

        this.field_3847 = 100;
        this.field_17867 = 3/16f;

        this.shouldSwirl = shouldSwirl;
        this.rotSpeed = 0f;
        this.spinAcceleration = 0f;
        this.swirlStrength = MathHelpers.randomBetween(5, 5);
        this.swirlPeriod = MathHelpers.randomBetween(100, 300);
    }

    protected void setInitialVelocity(double xSpeed, double ySpeed, double zSpeed, float variance) {
        this.field_3852 = xSpeed + ((field_3851.field_9229.method_43057() * variance) - (variance / 2));
        this.field_3869 = ySpeed + ((field_3851.field_9229.method_43057() * variance) - (variance / 2));
        this.field_3850 = zSpeed + ((field_3851.field_9229.method_43057() * variance) - (variance / 2));
    }

    @Override
    public @NotNull class_3999 method_18122() {
        return class_3999.field_17828;
    }

    public void applyGravity() {
        this.field_3869 -= (0.04f * this.field_3844);
    }

    protected void renderTick(float partialTicks) {}

    @Override
    public void method_3074(@NotNull class_4588 buffer, @NotNull class_4184 renderInfo, float partialTicks) {
        this.renderTick(partialTicks);
        super.method_3074(buffer, renderInfo, partialTicks);
    }

    @Override
    public void method_3070() {
        if (this.field_3843) return;

        this.field_3858 = this.field_3874;
        this.field_3838 = this.field_3854;
        this.field_3856 = this.field_3871;
        if (this.field_3866++ >= this.field_3847) {
            this.method_3085();
            return;
        }

        double swirlX = 0.0d;
        double swirlZ = 0.0d;
        if(shouldSwirl) {
            float swirlMultiplier = this.field_3866 * 0.08f;

            swirlX += (double) swirlMultiplier * Math.cos((double) swirlMultiplier * this.swirlPeriod) * (double) this.swirlStrength;
            swirlZ += (double) swirlMultiplier * Math.sin((double) swirlMultiplier * this.swirlPeriod) * (double) this.swirlStrength;
        }

        this.field_3852 += swirlX * 0.0025f;
        this.field_3850 += swirlZ * 0.0025f;
        this.applyGravity();
        this.method_3069(this.field_3852, this.field_3869, this.field_3850);

        this.rotSpeed += this.spinAcceleration / 20.0f;
        this.field_3857 = this.field_3839;
        this.field_3839 += this.rotSpeed / 20.0f;

        this.field_3852 *= this.field_28786;
        this.field_3869 *= this.field_28786;
        this.field_3850 *= this.field_28786;
    }
}

==> eg_particle_interactions-v0.8.4-fabric-mc1.21.10-sources.jar: games/enchanted/eg_particle_interactions/common/particle/swirling/SwirlingParticle.java <==
package games.enchanted.eg_particle_interactions.common.particle.swirling;

import games.enchanted.eg_particle_interactions.common.particle.compat.CustomGeometryParticle;
import games.enchanted.eg_particle_interactions.common.util.MathHelpers;
import net.minecraft.class_4002;
import net.minecraft.class_638;

//? if minecraft: > 1.21.8 {

//?}

public class SwirlingParticle extends CustomGeometryParticle {
    protected float rotSpeed;
    protected float spinAcceleration;
    protected double swirlPeriod;
    protected float swirlStrength;
    protected final boolean shouldSwirl;

    protected SwirlingParticle(class_638 level, double x, double y, double z, double xSpeed, double ySpeed, double zSpeed, class_4002 spriteSet, boolean shouldSwirl) {
        super(level, x, y, z, xSpeed, ySpeed, zSpeed, spriteSet.method_18139(level.field_9229));
        this.field_3852 = xSpeed;
        this.field_3869 = ySpeed;
        this.field_3850 = zSpeed;
        this.field_3844 = 0.5f;

        this.sprite = spriteSet.method_18139(level.field_9229);

        this.field_3847 = 100;
        this.setScale(3/16f);

        this.shouldSwirl = shouldSwirl;
        this.rotSpeed = 0f;
        this.spinAcceleration = 0f;
        this.swirlStrength = MathHelpers.randomBetween(5, 5);
        this.swirlPeriod = MathHelpers.randomBetween(100, 300);
    }

    protected void setInitialVelocity(double xSpeed, double ySpeed, double zSpeed, float variance) {
        this.field_3852 = xSpeed + ((field_3851.field_9229.method_43057() * variance) - (variance / 2));
        this.field_3869 = ySpeed + ((field_3851.field_9229.method_43057() * variance) - (variance / 2));
        this.field_3850 = zSpeed + ((field_3851.field_9229.method_43057() * variance) - (variance / 2));
    }

    public void applyGravity() {
        this.field_3869 -= (0.04f * this.field_3844);
    }

    @Override
    protected ParticleLayer getParticleLayer() {
        return ParticleLayer.OPAQUE;
    }

    @Override
    public void method_3070() {
        if (this.field_3843) return;

        this.field_3858 = this.field_3874;
        this.field_3838 = this.field_3854;
        this.field_3856 = this.field_3871;
        if (this.field_3866++ >= this.field_3847) {
            this.method_3085();
            return;
        }

        double swirlX = 0.0d;
        double swirlZ = 0.0d;
        if(shouldSwirl) {
            float swirlMultiplier = this.field_3866 * 0.08f;

            swirlX += (double) swirlMultiplier * Math.cos((double) swirlMultiplier * this.swirlPeriod) * (double) this.swirlStrength;
            swirlZ += (double) swirlMultiplier * Math.sin((double) swirlMultiplier * this.swirlPeriod) * (double) this.swirlStrength;
        }

        this.field_3852 += swirlX * 0.0025f;
        this.field_3850 += swirlZ * 0.0025f;
        this.applyGravity();
        this.method_3069(this.field_3852, this.field_3869, this.field_3850);

        this.rotSpeed += this.spinAcceleration / 20.0f;
        this.oRoll = this.roll;
        this.roll += this.rotSpeed / 20.0f;

        this.field_3852 *= this.field_28786;
        this.field_3869 *= this.field_28786;
        this.field_3850 *= this.field_28786;
    }
}
